==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-membership/src/integrationTest/java/org/apache/geode/distributed/internal/membership/gms/MembershipSanctionedSerializablesServiceIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.distributed.internal.membership.gms;

import org.junit.experimental.categories.Category;

import org.apache.geode.codeAnalysis.SanctionedSerializablesServiceIntegrationTestBase;
import org.apache.geode.internal.serialization.SanctionedSerializablesService;
import org.apache.geode.test.junit.categories.SanctionedSerializablesTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({SerializationTest.class, SanctionedSerializablesTest.class})
public class MembershipSanctionedSerializablesServiceIntegrationTest
    extends SanctionedSerializablesServiceIntegrationTestBase {

  private final SanctionedSerializablesService service =
      new MembershipSanctionedSerializablesService();

  @Override
  protected SanctionedSerializablesService getService() {
    return service;
  }

  @Override
  protected ServiceResourceExpectation getServiceResourceExpectation() {
    return ServiceResourceExpectation.NULL;
  }
}

==> apache-geode-1.15.1-src.tgz: apache-geode-1.15.1-src/geode-membership/src/integrationTest/java/org/apache/geode/distributed/internal/membership/gms/MembershipSanctionedSerializablesServiceIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.distributed.internal.membership.gms;

import org.junit.experimental.categories.Category;

import org.apache.geode.codeAnalysis.SanctionedSerializablesServiceIntegrationTestBase;
import org.apache.geode.internal.serialization.filter.SanctionedSerializablesService;
import org.apache.geode.test.junit.categories.SanctionedSerializablesTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({SerializationTest.class, SanctionedSerializablesTest.class})
public class MembershipSanctionedSerializablesServiceIntegrationTest
    extends SanctionedSerializablesServiceIntegrationTestBase {

  private final SanctionedSerializablesService service =
      new MembershipSanctionedSerializablesService();

  @Override
  protected SanctionedSerializablesService getService() {
    return service;
  }

  @Override
  protected ServiceResourceExpectation getServiceResourceExpectation() {
    return ServiceResourceExpectation.NULL;
  }
}
